==> vesper-0.4.7.tar.gz: vesper-0.4.7/vesper/django/app/static/vesper/clip-album/time-point-overlay.js <==
import { AnnotatingOverlay }
    from '/static/vesper/clip-album/annotating-overlay.js';
import { CommandableDelegate }
    from '/static/vesper/clip-album/keyboard-input-interpreter.js';
import { TimeFrequencyUtils }
    from '/static/vesper/clip-album/time-frequency-utils.js';


const _COMMAND_SPECS = [
    ['set_time_point'],
    ['clear_time_point']
];


const _commandableDelegate = new CommandableDelegate(_COMMAND_SPECS);


export class TimePointOverlay extends AnnotatingOverlay {


    constructor(clipView, settings) {
        super(clipView, settings, 'Time Point Overlay', _commandableDelegate)
        this.annotationName = settings.annotationName;
    }


    _executeSetTimePointCommand(env) {

        const e = this.clipView.lastMouseEvent;
        const tf = this.clipView.getMouseTimeAndFrequency(e);

        if (tf !== null)
            this._setTimeAnnotation(tf[0]);

    }


    _setTimeAnnotation(time) {
        
        const clip = this.clipView.clip;
        
        let index = null;
        
        if (time !== null) {
            
            const startIndex = clip.startIndex;
            
            if (startIndex === null) {
                // clip start index unknown
                
                window.alert(
                    `Cannot annotate clip because its start index is ` +
                    `unknown.`);
                
                return;
                
            }
                
            index = startIndex + Math.round(time * clip.sampleRate);
            
        }
            
        const annotations = new Object();
        annotations[this.annotationName] = index;

        this._annotateClip(clip.id, annotations);
        
    }
    
    
    _executeClearTimePointCommand(env) {
        this._setAnnotation(null);
    }


    render() {

        const annotations = this.clipView.clip.annotations;

        // console.log(
        //     `TimePointOverlay.render ${annotations} ` +
        //     `${this.annotationName}`);

        if (annotations !== null &&
                annotations.hasOwnProperty(this.annotationName)) {

            const index = parseInt(annotations[this.annotationName]);
            this._render(index);

        }

    }


    _render(index) {

        const clipView = this.clipView;
        const clip = clipView.clip;

        if (clip.startIndex === null) 
            // clip start index unknown

            return;
        
        const sampleRate = clip.sampleRate;
        const canvas = clipView.overlayCanvas;

        const time = (index - clip.startIndex) / clip.sampleRate;
        const startTime = 0;
        const endTime = clip.span;
        const x = Math.round(TimeFrequencyUtils.timeToViewX(
            time, startTime, endTime, canvas.width)) + .5;

        const context = canvas.getContext('2d');

        context.strokeStyle = 'orange';
        context.lineWidth = 1;
        context.lineCap = 'butt';
        context.lineStyle = 'solid';

        context.beginPath();
        context.moveTo(x, 0);
        context.lineTo(x, canvas.height);
        context.stroke();

    }


}

==> vesper-0.4.9.tar.gz: vesper-0.4.9/vesper/django/app/static/vesper/clip-album/time-point-overlay.js <==
import { AnnotatingOverlay }
    from '/static/vesper/clip-album/annotating-overlay.js';
import { CommandableDelegate }
    from '/static/vesper/clip-album/keyboard-input-interpreter.js';
import { TimeFrequencyUtils }
    from '/static/vesper/clip-album/time-frequency-utils.js';


const _COMMAND_SPECS = [
    ['set_time_point'],
    ['clear_time_point']
];


const _commandableDelegate = new CommandableDelegate(_COMMAND_SPECS);


export class TimePointOverlay extends AnnotatingOverlay {


    constructor(clipView, settings) {
        super(clipView, settings, 'Time Point Overlay', _commandableDelegate)
        this.annotationName = settings.annotationName;
    }


    _executeSetTimePointCommand(env) {

        const e = this.clipView.lastMouseEvent;
        const tf = this.clipView.getMouseTimeAndFrequency(e);

        if (tf !== null)
            this._setTimeAnnotation(tf[0]);

    }


    _setTimeAnnotation(time) {
        
        const clip = this.clipView.clip;
        
        let index = null;
        
        if (time !== null) {
            
            const startIndex = clip.startIndex;
            
            if (startIndex === null) {
                // clip start index unknown
                
                window.alert(
                    `Cannot annotate clip because its start index is ` +
                    `unknown.`);
                
                return;
                
            }
                
            index = startIndex + Math.round(time * clip.sampleRate);
            
        }
            
        const annotations = new Object();
        annotations[this.annotationName] = index;

        this._annotateClip(clip.id, annotations);
        
    }
    
    
    _executeClearTimePointCommand(env) {
        this._setTimeAnnotation(null);
    }


    render() {

        const annotations = this.clipView.clip.annotations;

        // console.log(
        //     `TimePointOverlay.render ${annotations} ` +
        //     `${this.annotationName}`);

        if (annotations !== null &&
                annotations.hasOwnProperty(this.annotationName)) {

            const index = parseInt(annotations[this.annotationName]);
            this._render(index);

        }

    }


    _render(index) {

        const clipView = this.clipView;
        const clip = clipView.clip;

        if (clip.startIndex === null) 
            // clip start index unknown

            return;
        
        const sampleRate = clip.sampleRate;
        const canvas = clipView.overlayCanvas;

        const time = (index - clip.startIndex) / clip.sampleRate;
        const startTime = 0;
        const endTime = clip.span;
        const x = Math.round(TimeFrequencyUtils.timeToViewX(
            time, startTime, endTime, canvas.width)) + .5;

        const context = canvas.getContext('2d');

        context.strokeStyle = 'orange';
        context.lineWidth = 1;
        context.lineCap = 'butt';
        context.lineStyle = 'solid';

        context.beginPath();
        context.moveTo(x, 0);
        context.lineTo(x, canvas.height);
        context.stroke();

    }


}
